# Python Package Exercise

## Badge

![Python build & test](https://github.com/software-students-fall2023/3-python-package-exercise-kungheifatchoy/actions/workflows/python-package.yml/badge.svg)


## Project Description

A python package designed to facilitate the solving and manipulation of quadratic equations.

## Instructions

*write instructions here*


## Code Examples

` # code example for how a developer who wants to import your project into their own code can do so - include documentation for all functions in your package and a link to an example Python program that uses each of them.`

` # code example for how a developer who wants to contribute to your project can set up the virtual environment, install dependencies, and build and test your package for themselves.`


## Team Names

Nicolas Izurieta: https://github.com/ni2050

Patrick Zhao: https://github.com/PatrickZhao0

Brad Yin: https://github.com/BREADLuVER

Yucheng Xu: https://github.com/Yucheng-XPH


## Link to Package

https://pypi.org/project/pyquadratic/

